PAWpySeed: pawpyseed.core.projector.CopyPseudoWavefunction Class Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Member Functions | Public Attributes | List of all members
pawpyseed.core.projector.CopyPseudoWavefunction Class Reference
Inheritance diagram for pawpyseed.core.projector.CopyPseudoWavefunction:
[legend]
Collaboration diagram for pawpyseed.core.projector.CopyPseudoWavefunction:
[legend]

## Public Member Functions
def | __init__ (self, wf_ptr, kpts, kws)
Public Member Functions inherited from pawpyseed.core.wavefunction.PseudoWavefunction
def | __init__ (self, filename="WAVECAR", vr="vasprun.xml")
def | pseudoprojection (self, band_num, basis)

## Public Attributes
| wf_ptr
| kpts
| kws
| ncl
Public Attributes inherited from pawpyseed.core.wavefunction.PseudoWavefunction
| kws
| kpts
| wf_ptr
| ncl

## Constructor & Destructor Documentation

def pawpyseed.core.projector.CopyPseudoWavefunction.__init__ | ( |  | self,
|  |  | wf_ptr,
|  |  | kpts,
|  |  | kws
| ) |  |

## Member Data Documentation

pawpyseed.core.projector.CopyPseudoWavefunction.kpts

pawpyseed.core.projector.CopyPseudoWavefunction.kws

pawpyseed.core.projector.CopyPseudoWavefunction.ncl

pawpyseed.core.projector.CopyPseudoWavefunction.wf_ptr

The documentation for this class was generated from the following file:

- /home/kyle/Research/projects/pawpyseed/pawpyseed/core/projector.py